@@ -2,14 +2,15 @@ use strict;
 use warnings;
 
 package Net::Amazon::Route53;
-$Net::Amazon::Route53::VERSION = '0.160530';
+$Net::Amazon::Route53::VERSION = '0.173450';
 use LWP::UserAgent;
 use HTTP::Request;
 use Digest::HMAC_SHA1;
 use MIME::Base64;
 use XML::Bare;
 use HTML::Entities;
-use Any::Moose;
+use Moo;
+use Types::Standard qw(InstanceOf Str);
 
 use Net::Amazon::Route53::HostedZone;
 use Net::Amazon::Route53::ResourceRecordSet::Change;
@@ -43,8 +44,8 @@ The Amazon key, needed to contact Amazon's Route 53.
 
 =cut
 
-has 'id'  => (is => 'rw', isa => 'Str', required => 1,);
-has 'key' => (is => 'rw', isa => 'Str', required => 1,);
+has 'id'  => ( is => 'rw', isa => Str, required => 1, );
+has 'key' => ( is => 'rw', isa => Str, required => 1, );
 
 =head3 ua
 
@@ -55,7 +56,7 @@ Amazon's Route 53
 
 has 'ua' => (
     is       => 'rw',
-    isa      => 'LWP::UserAgent',
+    isa      => InstanceOf['LWP::UserAgent'],
     required => 1,
     default  => sub {
         my $self = shift;
@@ -80,14 +81,14 @@ request. Dies on error, showing the request's error given by the API.
 
 =cut
 
-sub request {
+sub request
+{
     my $self   = shift;
     my $method = shift;
     my $uri    = shift;
 
     return unless $method;
-    return
-        unless ($method eq 'get' or $method eq 'post' or $method eq 'delete');
+    return unless ( $method eq 'get' or $method eq 'post' or $method eq 'delete' );
     return unless $uri;
 
     # Get amazon server's date
@@ -97,35 +98,33 @@ sub request {
     };
 
     # Create signed request
-    my $hmac = Digest::HMAC_SHA1->new($self->key);
+    my $hmac = Digest::HMAC_SHA1->new( $self->key );
     $hmac->add($date);
-    my $signature = encode_base64($hmac->digest, '');
+    my $signature = encode_base64( $hmac->digest, '' );
 
     my %options = (
-        'Date'                 => $date,
-        'X-Amzn-Authorization' => sprintf(
-            "AWS3-HTTPS AWSAccessKeyId=%s,Algorithm=HmacSHA1,Signature=%s",
-            $self->id, $signature
-        ),
+        'Date' => $date,
+        'X-Amzn-Authorization' =>
+          sprintf( "AWS3-HTTPS AWSAccessKeyId=%s,Algorithm=HmacSHA1,Signature=%s", $self->id, $signature ),
         @_
     );
     my $content = delete $options{Content};
     my $request = HTTP::Request->new(
-        uc $method, $uri,
-        [map {$_ => $options{$_}} keys %options],
+        uc $method,
+        $uri,
+        [ map { $_ => $options{$_} } keys %options],
         $content ? $content : undef,
     );
-    my $rc = $self->ua->request($request);
+    my $rc = $self->ua->request( $request );
     die "Could not perform request $method on $uri: "
-        . $rc->status_line . "\n"
-        . $rc->decoded_content . "\n"
-        . "Original request: "
-        . (defined $content ? $content : '') . "\n"
-        unless $rc->is_success;
-
+      . $rc->status_line . "\n"
+      . $rc->decoded_content . "\n"
+      . "Original request: "
+      . ( defined $content ? $content : '' ) . "\n"
+      unless $rc->is_success;
     #use YAML;warn "\n\nmethod $method to $uri @_: " . Dump($rc);
-    my $resp = XML::Bare::xmlin($rc->decoded_content);
-    die "Error: $resp->{Error}{Code}\n" if (exists $resp->{Error});
+    my $resp = XML::Bare::xmlin( $rc->decoded_content );
+    die "Error: $resp->{Error}{Code}\n" if ( exists $resp->{Error} );
     return $resp;
 }
 
@@ -142,21 +141,17 @@ Takes an optional parameter indicating the name of the wanted hosted zone.
 
 =cut
 
-sub get_hosted_zones {
+sub get_hosted_zones
+{
     my $self         = shift;
     my $which        = shift;
     my $start_marker = '';
     my @zones;
     while (1) {
-        my $resp = $self->request('get',
-            'https://route53.amazonaws.com/2010-10-01/hostedzone?maxitems=100'
-                . $start_marker);
-        if ($resp->{HostedZones}) {
-            push @zones,
-                (
-                ref $resp->{HostedZones}{HostedZone} eq 'ARRAY'
-                ? @{ $resp->{HostedZones}{HostedZone} }
-                : $resp->{HostedZones}{HostedZone});
+        my $resp =
+          $self->request( 'get', 'https://route53.amazonaws.com/2010-10-01/hostedzone?maxitems=100' . $start_marker );
+        if($resp->{HostedZones}) { 
+            push @zones, ( ref $resp->{HostedZones}{HostedZone} eq 'ARRAY' ? @{ $resp->{HostedZones}{HostedZone} } : $resp->{HostedZones}{HostedZone} );
         }
         last if $resp->{IsTruncated} eq 'false';
         $start_marker = '?marker=' . $resp->{NextMarker};
@@ -164,16 +159,13 @@ sub get_hosted_zones {
     my @o_zones;
     for my $zone (@zones) {
         push @o_zones,
-            Net::Amazon::Route53::HostedZone->new(
+          Net::Amazon::Route53::HostedZone->new(
             route53 => $self,
-            (map {lc($_) => $zone->{$_}} qw/Id Name CallerReference/),
-            comment =>
-                (exists $zone->{Config} and ref $zone->{Config} eq 'HASH')
-            ? $zone->{Config}{Comment}
-            : '',
-            );
+            ( map { lc($_) => $zone->{$_} } qw/Id Name CallerReference/ ),
+            comment => (exists $zone->{Config} and ref $zone->{Config} eq 'HASH') ?  $zone->{Config}{Comment} : '',
+          );
     }
-    @o_zones = grep {$_->name eq $which} @o_zones if $which;
+    @o_zones = grep { $_->name eq $which } @o_zones if $which;
     return @o_zones;
 }
 
@@ -195,7 +187,8 @@ requested.
 
 =cut
 
-sub batch_create {
+sub batch_create
+{
     my $self  = shift;
     my $batch = shift;
     my $wait  = shift;
@@ -203,14 +196,16 @@ sub batch_create {
 
     die "Your batch is not an arrayref" unless ref($batch) eq 'ARRAY';
     my @invalid =
-        grep {!($_->isa("Net::Amazon::Route53::ResourceRecordSet"))} @$batch;
+        grep { !( $_->isa("Net::Amazon::Route53::ResourceRecordSet") ) }
+        @$batch;
     die
         "Your batch is not an arrayref of Net::Amazon::Route53::ResourceRecordSets"
         if scalar(@invalid);
 
     my $hostedzone_id = $batch->[0]->hostedzone->id;
-    my @wrong_zone = grep {$_->hostedzone->id ne $hostedzone_id} @$batch;
-    die "Your batch contains records from different hosted zones"
+    my @wrong_zone = grep { $_->hostedzone->id ne $hostedzone_id } @$batch;
+    die
+        "Your batch contains records from different hosted zones"
         if scalar(@wrong_zone);
 
     $hostedzone_id =~ s/^\///g;
@@ -218,8 +213,7 @@ sub batch_create {
     my $batch_xml = $self->_batch_request_header;
 
     for my $rr (@$batch) {
-        $rr->name =~ /\.$/
-            or die "Zone name needs to end in a dot, to be created\n";
+        $rr->name =~ /\.$/ or die "Zone name needs to end in a dot, to be created\n";
         my $change_xml = $self->_get_create_xml($rr);
         $batch_xml .= $change_xml;
     }
@@ -233,14 +227,11 @@ sub batch_create {
     );
     my $change = Net::Amazon::Route53::Change->new(
         route53 => $self,
-        (
-            map {lc($_) => decode_entities($resp->{ChangeInfo}{$_})}
-                qw/Id Status SubmittedAt/
-        ),
+        ( map { lc($_) => decode_entities($resp->{ChangeInfo}{$_}) } qw/Id Status SubmittedAt/ ),
     );
     $change->refresh();
     return $change if !$wait;
-    while (lc($change->status) ne 'insync') {
+    while ( lc( $change->status ) ne 'insync' ) {
         sleep 2;
         $change->refresh();
     }
@@ -280,16 +271,16 @@ requested.
 =cut
 
 sub atomic_update {
-    my $self     = shift;
+    my $self  = shift;
     my $original = shift;
-    my $new      = shift;
-    my $wait     = shift;
+    my $new = shift;
+    my $wait  = shift;
     $wait = 0 if !defined $wait;
 
-    for my $rrset (($original, $new)) {
+    for my $rrset (($original,$new)) {
         die "A record set is not an arrayref" unless ref($rrset) eq 'ARRAY';
         my @invalid =
-            grep {!($_->isa("Net::Amazon::Route53::ResourceRecordSet"))}
+            grep { !( $_->isa("Net::Amazon::Route53::ResourceRecordSet") ) }
             @$rrset;
         die
             "A record set is not an arrayref of Net::Amazon::Route53::ResourceRecordSets"
@@ -297,24 +288,22 @@ sub atomic_update {
     }
 
     my $hostedzone_id = $original->[0]->hostedzone->id;
-    my @wrong_zone =
-        grep {$_->hostedzone->id ne $hostedzone_id} (@$original, @$new);
-    die "A record set contains records from different hosted zones"
+    my @wrong_zone = grep { $_->hostedzone->id ne $hostedzone_id } (@$original,@$new);
+    die
+        "A record set contains records from different hosted zones"
         if scalar(@wrong_zone);
 
     $hostedzone_id =~ s/^\///g;
 
-    my %original    = map {$_->name . '-' . $_->type => 1} @$original;
-    my %new         = map {$_->name . '-' . $_->type => 1} @$new;
-    my %new_records = map {$_->name . '-' . $_->type => $_} @$new;
-    my @creates =
-        grep {!(defined $original{ $_->name . '-' . $_->type })} @$new;
-    my @deletions =
-        grep {!(defined $new{ $_->name . '-' . $_->type })} @$original;
-    my %deleted = map {$_->name . '-' . $_->type => 1} @deletions;
-    my @changes =
-        grep {defined $new{ $_->name . '-' . $_->type }}
-        grep {!(defined $deleted{ $_->name . '-' . $_->type })} @$original;
+    my %original = map { $_->name . '-' . $_->type => 1 } @$original;
+    my %new      = map { $_->name . '-' . $_->type => 1 } @$new;
+    my %new_records = map { $_->name . '-' . $_->type => $_ } @$new;
+    my @creates = grep { !( defined $original{ $_->name . '-' . $_->type } ) } @$new;
+    my @deletions = grep { !( defined $new{ $_->name . '-' . $_->type } ) } @$original;
+    my %deleted = map { $_->name . '-' . $_->type => 1 } @deletions;
+    my @changes = grep { defined $new{ $_->name . '-' . $_->type } }
+        grep { !( defined $deleted{ $_->name . '-' . $_->type } ) }
+        @$original;
     my @change_objects = map {
         Net::Amazon::Route53::ResourceRecordSet::Change->new(
             route53         => $_->route53,
@@ -325,34 +314,34 @@ sub atomic_update {
             original_values => $_->values,
             values          => $new_records{ $_->name . '-' . $_->type }->values
             )
-        } grep {
-        join(',', @{ $_->values }) ne
-            join(',', @{ $new_records{ $_->name . '-' . $_->type }->values })
-        } @changes;
+    }
+    grep {
+        join( ',', @{$_->values} ) ne
+            join( ',', @{$new_records{ $_->name . '-' . $_->type }->values} )
+    } @changes;
 
     my $batch_xml = $self->_batch_request_header;
 
     # Do not attempt to push an empty changeset
-    return Net::Amazon::Route53::Change->new(route53 => $self, status => 'NOOP')
-        if @change_objects + @deletions + @creates < 1;
+    return Net::Amazon::Route53::Change->new(
+        route53 => $self,
+        status  => 'NOOP'
+    ) if @change_objects + @deletions + @creates < 1;
 
     for my $rr (@change_objects) {
-        $rr->name =~ /\.$/
-            or die "Zone name needs to end in a dot, to be changed\n";
+        $rr->name =~ /\.$/ or die "Zone name needs to end in a dot, to be changed\n";
         my $change_xml = $self->_get_change_xml($rr);
         $batch_xml .= $change_xml;
     }
 
     for my $rr (@deletions) {
-        $rr->name =~ /\.$/
-            or die "Zone name needs to end in a dot, to be deleted\n";
+        $rr->name =~ /\.$/ or die "Zone name needs to end in a dot, to be deleted\n";
         my $change_xml = $self->_get_delete_xml($rr);
         $batch_xml .= $change_xml;
     }
 
     for my $rr (@creates) {
-        $rr->name =~ /\.$/
-            or die "Zone name needs to end in a dot, to be created\n";
+        $rr->name =~ /\.$/ or die "Zone name needs to end in a dot, to be created\n";
         my $change_xml = $self->_get_create_xml($rr);
         $batch_xml .= $change_xml;
     }
@@ -366,14 +355,11 @@ sub atomic_update {
     );
     my $change = Net::Amazon::Route53::Change->new(
         route53 => $self,
-        (
-            map {lc($_) => decode_entities($resp->{ChangeInfo}{$_})}
-                qw/Id Status SubmittedAt/
-        ),
+        ( map { lc($_) => decode_entities($resp->{ChangeInfo}{$_}) } qw/Id Status SubmittedAt/ ),
     );
     $change->refresh();
     return $change if !$wait;
-    while (lc($change->status) ne 'insync') {
+    while ( lc( $change->status ) ne 'insync' ) {
         sleep 2;
         $change->refresh();
     }
@@ -402,15 +388,16 @@ sub batch_change {
 
     die "Your batch is not an arrayref" unless ref($batch) eq 'ARRAY';
     my @invalid =
-        grep {!($_->isa("Net::Amazon::Route53::ResourceRecordSet::Change"))}
+        grep { !( $_->isa("Net::Amazon::Route53::ResourceRecordSet::Change") ) }
         @$batch;
     die
         "Your batch is not an arrayref of Net::Amazon::Route53::ResourceRecordSet::Changes"
         if scalar(@invalid);
 
     my $hostedzone_id = $batch->[0]->hostedzone->id;
-    my @wrong_zone = grep {$_->hostedzone->id ne $hostedzone_id} @$batch;
-    die "Your batch contains records from different hosted zones"
+    my @wrong_zone = grep { $_->hostedzone->id ne $hostedzone_id } @$batch;
+    die
+        "Your batch contains records from different hosted zones"
         if scalar(@wrong_zone);
 
     $hostedzone_id =~ s/^\///g;
@@ -418,8 +405,7 @@ sub batch_change {
     my $batch_xml = $self->_batch_request_header;
 
     for my $rr (@$batch) {
-        $rr->name =~ /\.$/
-            or die "Zone name needs to end in a dot, to be created\n";
+        $rr->name =~ /\.$/ or die "Zone name needs to end in a dot, to be created\n";
         my $change_xml = $self->_get_change_xml($rr);
         $batch_xml .= $change_xml;
     }
@@ -433,14 +419,11 @@ sub batch_change {
     );
     my $change = Net::Amazon::Route53::Change->new(
         route53 => $self,
-        (
-            map {lc($_) => decode_entities($resp->{ChangeInfo}{$_})}
-                qw/Id Status SubmittedAt/
-        ),
+        ( map { lc($_) => decode_entities($resp->{ChangeInfo}{$_}) } qw/Id Status SubmittedAt/ ),
     );
     $change->refresh();
     return $change if !$wait;
-    while (lc($change->status) ne 'insync') {
+    while ( lc( $change->status ) ne 'insync' ) {
         sleep 2;
         $change->refresh();
     }
@@ -456,7 +439,7 @@ to create that single record.
 =cut
 
 sub _get_create_xml {
-    my ($self, $record) = @_;
+    my ($self,$record) = @_;
     my $create_xml_str = <<'ENDXML';
         <Change>
             <Action>CREATE</Action>
@@ -471,14 +454,12 @@ sub _get_create_xml {
          </Change>
 ENDXML
 
-    my $create_xml = sprintf(
-        $create_xml_str,
-        map {$_} $record->name,
-        $record->type,
-        $record->ttl,
-        join("\n",
-            map {"<ResourceRecord><Value>" . $_ . "</Value></ResourceRecord>"}
-                @{ $record->values }));
+    my $create_xml = sprintf( $create_xml_str,
+        map { $_ }
+        $record->name, $record->type, $record->ttl,
+        join( "\n", map {
+            "<ResourceRecord><Value>" . $_ . "</Value></ResourceRecord>"
+        } @{ $record->values } ) );
 
     return $create_xml;
 }
@@ -492,7 +473,7 @@ that single record.
 =cut
 
 sub _get_delete_xml {
-    my ($self, $record) = @_;
+    my ($self,$record) = @_;
     my $delete_xml_str = <<'ENDXML';
         <Change>
             <Action>DELETE</Action>
@@ -507,14 +488,12 @@ sub _get_delete_xml {
          </Change>
 ENDXML
 
-    my $delete_xml = sprintf(
-        $delete_xml_str,
-        map {$_} $record->name,
-        $record->type,
-        $record->ttl,
-        join("\n",
-            map {"<ResourceRecord><Value>" . $_ . "</Value></ResourceRecord>"}
-                @{ $record->values }));
+    my $delete_xml = sprintf( $delete_xml_str,
+        map { $_ }
+        $record->name, $record->type, $record->ttl,
+        join( "\n", map {
+            "<ResourceRecord><Value>" . $_ . "</Value></ResourceRecord>"
+        } @{ $record->values } ) );
 
     return $delete_xml;
 }
@@ -528,7 +507,7 @@ to change, i.e., delete and create, that single record.
 =cut
 
 sub _get_change_xml {
-    my ($self, $record) = @_;
+    my ($self,$record) = @_;
     my $change_xml_str = <<'ENDXML';
         <Change>
             <Action>DELETE</Action>
@@ -554,16 +533,11 @@ sub _get_change_xml {
         </Change>
 ENDXML
 
-    my $change_xml = sprintf(
-        $change_xml_str,
-        (map {$_} ($record->name, $record->type, $record->ttl,)),
-        join("\n",
-            map {"<ResourceRecord><Value>" . $_ . "</Value></ResourceRecord>"}
-                @{ $record->original_values }),
-        (map {$_} ($record->name, $record->type, $record->ttl,)),
-        join("\n",
-            map {"<ResourceRecord><Value>" . $_ . "</Value></ResourceRecord>"}
-                @{ $record->values }));
+    my $change_xml = sprintf( $change_xml_str,
+        (map { $_ } ( $record->name, $record->type, $record->ttl, ) ),
+        join( "\n", map { "<ResourceRecord><Value>" . $_ . "</Value></ResourceRecord>" } @{ $record->original_values } ),
+        (map { $_ } ( $record->name, $record->type, $record->ttl, ) ),
+        join( "\n", map { "<ResourceRecord><Value>" . $_ . "</Value></ResourceRecord>" } @{ $record->values } ) );
     return $change_xml;
 }
 
@@ -574,7 +548,7 @@ Private method for xml templating. Returns a header string.
 =cut
 
 sub _batch_request_header {
-    my $self   = shift;
+    my $self = shift;
     my $header = <<'ENDXML';
 <?xml version="1.0" encoding="UTF-8"?>
 <ChangeResourceRecordSetsRequest xmlns="https://route53.amazonaws.com/doc/2010-10-01/">
@@ -592,7 +566,7 @@ Private method for xml templating. Returns a footer string.
 =cut
 
 sub _batch_request_footer {
-    my $self   = shift;
+    my $self = shift;
     my $footer = <<'ENDXML';
         </Changes>
    </ChangeBatch>
