@@ -2,8 +2,9 @@ use strict;
 use warnings;
 
 package Net::Amazon::Route53::Change;
-$Net::Amazon::Route53::Change::VERSION = '0.160530';
-use Any::Moose;
+$Net::Amazon::Route53::Change::VERSION = '0.173450';
+use Moo;
+use Types::Standard qw(InstanceOf Str);
 use HTML::Entities;
 
 =head2 SYNOPSIS
@@ -24,8 +25,7 @@ to Amazon's Route 53 service
 
 =cut
 
-has 'route53' =>
-    (is => 'rw', isa => 'Net::Amazon::Route53', required => 1, weak_ref => 1);
+has 'route53' => ( is => 'rw', isa => InstanceOf['Net::Amazon::Route53'], required => 1, weak_ref => 1 );
 
 =head3 id
 
@@ -46,9 +46,9 @@ Any Comment given when the zone is created
 
 =cut
 
-has 'id'          => (is => 'rw', isa => 'Str', required => 1, default => '');
-has 'status'      => (is => 'rw', isa => 'Str', required => 1, default => '');
-has 'submittedat' => (is => 'rw', isa => 'Str', required => 1, default => '');
+has 'id'          => ( is => 'rw', isa => Str, required => 1, default => '' );
+has 'status'      => ( is => 'rw', isa => Str, required => 1, default => '' );
+has 'submittedat' => ( is => 'rw', isa => Str, required => 1, default => '' );
 
 =head2 METHODS
 
@@ -60,20 +60,18 @@ Refresh the details of the change. When performed, the object's status is curren
 
 =cut
 
-sub refresh {
+sub refresh
+{
     my $self = shift;
     die "Cannot refresh without an id\n" unless length $self->id;
-    my $resp =
-        $self->route53->request('get',
-        'https://route53.amazonaws.com/2010-10-01/' . $self->id,
-        );
+    my $resp = $self->route53->request( 'get', 'https://route53.amazonaws.com/2010-10-01/' . $self->id, );
     for (qw/Id Status SubmittedAt/) {
         my $method = lc $_;
-        $self->$method(decode_entities($resp->{ChangeInfo}{$_}));
+        $self->$method( decode_entities( $resp->{ChangeInfo}{$_} ) );
     }
 }
 
-no Any::Moose;
+no Moo;
 
 =head1 AUTHOR
 
