@@ -2,8 +2,9 @@ use strict;
 use warnings;
 
 package Net::Amazon::Route53::HostedZone;
-$Net::Amazon::Route53::HostedZone::VERSION = '0.160530';
-use Any::Moose;
+$Net::Amazon::Route53::HostedZone::VERSION = '0.173450';
+use Moo;
+use Types::Standard qw(InstanceOf Str ArrayRef);
 use HTML::Entities;
 
 use Net::Amazon::Route53::Change;
@@ -27,8 +28,7 @@ to Amazon's Route 53 service
 
 =cut
 
-has 'route53' =>
-    (is => 'rw', isa => 'Net::Amazon::Route53', required => 1, weak_ref => 1);
+has 'route53' => ( is => 'rw', isa => InstanceOf['Net::Amazon::Route53'], required => 1, weak_ref => 1 );
 
 =head3 id
 
@@ -50,11 +50,10 @@ Any Comment given when the zone is created
 
 =cut
 
-has 'id'   => (is => 'rw', isa => 'Str', required => 1, default => '');
-has 'name' => (is => 'rw', isa => 'Str', required => 1, default => '');
-has 'callerreference' =>
-    (is => 'rw', isa => 'Str', required => 1, default => '');
-has 'comment' => (is => 'rw', isa => 'Str', required => 1, default => '');
+has 'id'              => ( is => 'rw', isa => Str, required => 1, default => '' );
+has 'name'            => ( is => 'rw', isa => Str, required => 1, default => '' );
+has 'callerreference' => ( is => 'rw', isa => Str, required => 1, default => '' );
+has 'comment'         => ( is => 'rw', isa => Str, required => 1, default => '' );
 
 =head3 nameservers
 
@@ -64,16 +63,15 @@ Lazily loaded, returns a list of the nameservers authoritative for this zone
 
 has 'nameservers' => (
     is      => 'rw',
-    isa     => 'ArrayRef[Str]',
+    isa     => ArrayRef[Str],
     lazy    => 1,
     default => sub {
-        my $self = shift;
-        my $resp = $self->route53->request('get',
-            'https://route53.amazonaws.com/2010-10-01/' . $self->id);
-        my @nameservers = map {decode_entities($_)}
-            @{ $resp->{DelegationSet}{NameServers}{NameServer} };
+        my $self        = shift;
+        my $resp        = $self->route53->request( 'get', 'https://route53.amazonaws.com/2010-10-01/' . $self->id );
+        my @nameservers = map { decode_entities($_) } @{ $resp->{DelegationSet}{NameServers}{NameServer} };
         \@nameservers;
-    });
+    }
+);
 
 =head3 resource_record_sets
 
@@ -84,10 +82,10 @@ Lazily loaded, returns a list of the resource record sets
 
 has 'resource_record_sets' => (
     is      => 'rw',
-    isa     => 'ArrayRef',
+    isa     => ArrayRef,
     lazy    => 1,
     default => sub {
-        my $self             = shift;
+        my $self = shift;
         my $next_record_name = '';
         my @resource_record_sets;
         while (1) {
@@ -98,28 +96,29 @@ has 'resource_record_sets' => (
                     . $next_record_name);
             my $set = $resp->{ResourceRecordSets}{ResourceRecordSet};
             my @results = ref($set) eq 'ARRAY' ? @$set : ($set);
-            for my $res (@results) {
+            for my $res ( @results ) {
                 push @resource_record_sets,
-                    Net::Amazon::Route53::ResourceRecordSet->new(
+                  Net::Amazon::Route53::ResourceRecordSet->new(
                     route53    => $self->route53,
                     hostedzone => $self,
                     name       => decode_entities($res->{Name}),
                     ttl        => $res->{TTL} || 0,
                     type       => decode_entities($res->{Type}),
                     values     => [
-                        map {decode_entities($_->{Value})} @{
-                            ref $res->{ResourceRecords}{ResourceRecord} eq
-                                'ARRAY'
+                        map { decode_entities($_->{Value}) } @{
+                            ref $res->{ResourceRecords}{ResourceRecord} eq 'ARRAY'
                             ? $res->{ResourceRecords}{ResourceRecord}
-                            : [$res->{ResourceRecords}{ResourceRecord}] }
+                            : [ $res->{ResourceRecords}{ResourceRecord} ]
+                        }
                     ],
-                    );
+                );
             }
             last unless $resp->{NextRecordName};
-            $next_record_name = '&name=' . $resp->{NextRecordName};
+            $next_record_name = '&name='.$resp->{NextRecordName};
         }
         \@resource_record_sets;
-    });
+    }
+);
 
 =head2 METHODS
 
@@ -137,12 +136,12 @@ Returns a L<Net::Amazon::Route53::Change> object representing the change request
 
 =cut
 
-sub create {
+sub create
+{
     my $self = shift;
     my $wait = shift;
     $wait = 0 if !defined $wait;
-    $self->name =~ /\.$/
-        or die "Zone name needs to end in a dot, to be created\n";
+    $self->name =~ /\.$/ or die "Zone name needs to end in a dot, to be created\n";
     my $request_xml_str = <<'ENDXML';
 <?xml version="1.0" encoding="UTF-8"?>
 <CreateHostedZoneRequest xmlns="https://route53.amazonaws.com/doc/2010-10-01/">
@@ -153,26 +152,22 @@ sub create {
     </HostedZoneConfig>
 </CreateHostedZoneRequest>
 ENDXML
-    my $request_xml = sprintf($request_xml_str,
-        map {$_} $self->name,
-        $self->callerreference, $self->comment);
+    my $request_xml = sprintf( $request_xml_str, map { $_ } $self->name, $self->callerreference, $self->comment );
     my $resp = $self->route53->request(
-        'post', 'https://route53.amazonaws.com/2010-10-01/hostedzone',
+        'post',
+        'https://route53.amazonaws.com/2010-10-01/hostedzone',
         'content-type' => 'text/xml; charset=UTF-8',
-        Content        => $request_xml,
+        Content => $request_xml,
     );
-    $self->id($resp->{HostedZone}{Id});
+    $self->id( $resp->{HostedZone}{Id} );
     my $change = Net::Amazon::Route53::Change->new(
         route53 => $self->route53,
-        (
-            map {lc($_) => decode_entities($resp->{ChangeInfo}{$_})}
-                qw/Id Status SubmittedAt/
-        ),
+        ( map { lc($_) => decode_entities($resp->{ChangeInfo}{$_}) } qw/Id Status SubmittedAt/ ),
     );
     $change->refresh();
     return $change if !$wait;
 
-    while (lc($change->status) ne 'insync') {
+    while ( lc( $change->status ) ne 'insync' ) {
         sleep 2;
         $change->refresh();
     }
@@ -192,31 +187,26 @@ Returns a L<Net::Amazon::Route53::Change> object representing the change request
 
 =cut
 
-sub delete {
+sub delete
+{
     my $self = shift;
     my $wait = shift;
     $wait = 0 if !defined $wait;
-    my $resp =
-        $self->route53->request('delete',
-        'https://route53.amazonaws.com/2010-10-01/' . $self->id,
-        );
+    my $resp = $self->route53->request( 'delete', 'https://route53.amazonaws.com/2010-10-01/' . $self->id, );
     my $change = Net::Amazon::Route53::Change->new(
         route53 => $self->route53,
-        (
-            map {lc($_) => decode_entities($resp->{ChangeInfo}{$_})}
-                qw/Id Status SubmittedAt/
-        ),
+        ( map { lc($_) => decode_entities($resp->{ChangeInfo}{$_}) } qw/Id Status SubmittedAt/ ),
     );
     $change->refresh();
     return $change if !$wait;
-    while (lc($change->status) ne 'insync') {
+    while ( lc( $change->status ) ne 'insync' ) {
         sleep 2;
         $change->refresh();
     }
     return $change;
 }
 
-no Any::Moose;
+no Moo;
 
 =head1 AUTHOR
 
